import { Plugin, type SegmentClient, PluginType, SegmentEvent } from '..';
export interface CategoryConsentStatusProvider {
    setApplicableCategories(categories: string[]): void;
    getConsentStatus(): Promise<Record<string, boolean>>;
    onConsentChange(cb: (updConsent: Record<string, boolean>) => void): void;
    shutdown?(): void;
}
/**
 * This plugin interfaces with the consent provider and it:
 *
 * - stamps all events with the consent metadata.
 * - augments all destinations with a consent filter plugin that prevents events from reaching them if
 * they are not compliant current consent setup
 * - listens for consent change from the provider and notifies Segment
 */
export declare class ConsentPlugin extends Plugin {
    type: PluginType;
    private consentCategoryProvider;
    private categories;
    constructor(consentCategoryProvider: CategoryConsentStatusProvider, categories: string[]);
    configure(analytics: SegmentClient): void;
    execute(event: SegmentEvent): Promise<SegmentEvent>;
    shutdown(): void;
    private injectConsentFilterIfApplicable;
    private isDestinationPlugin;
    private containsConsentSettings;
    private isConsentUpdateEvent;
    private hasUnmappedDestinations;
    private isConsentFeatureSetup;
}
//# sourceMappingURL=ConsentPlugin.d.ts.map